summaryrefslogtreecommitdiff
path: root/sw/source/ui/app
diff options
context:
space:
mode:
authorMiklos Vajna <vmiklos@collabora.co.uk>2013-10-26 19:50:13 +0200
committerMiklos Vajna <vmiklos@collabora.co.uk>2013-10-26 20:03:50 +0200
commitee3189489c0205ec221fbc907a01c711b58fc42e (patch)
tree1cd2fd05e3518d9484b11f0fc29b6e458a629338 /sw/source/ui/app
parent2e99447fc07df98ebbc343ef79852b7eaf7b7757 (diff)
sw: ViewShell -> SwViewShell rename
It's a public class, so it should have the 'Sw' prefix. Change-Id: I0040c1cc37ffcba7fc5f58b71c86f4a7cb0bfce4
Diffstat (limited to 'sw/source/ui/app')
-rw-r--r--sw/source/ui/app/apphdl.cxx2
-rw-r--r--sw/source/ui/app/docsh.cxx2
-rw-r--r--sw/source/ui/app/docsh2.cxx2
-rw-r--r--sw/source/ui/app/swmodul1.cxx8
4 files changed, 7 insertions, 7 deletions
diff --git a/sw/source/ui/app/apphdl.cxx b/sw/source/ui/app/apphdl.cxx
index d73fcfb8edaf..8582adb97e48 100644
--- a/sw/source/ui/app/apphdl.cxx
+++ b/sw/source/ui/app/apphdl.cxx
@@ -793,7 +793,7 @@ void SwModule::ConfigurationChanged( utl::ConfigurationBroadcaster* pBrdCst, sal
if( pObjSh->IsA(TYPE(SwDocShell)) )
{
const SwDoc* pDoc = ((SwDocShell*)pObjSh)->GetDoc();
- ViewShell* pVSh = 0;
+ SwViewShell* pVSh = 0;
pDoc->GetEditShell( &pVSh );
if ( pVSh )
pVSh->ChgNumberDigits();
diff --git a/sw/source/ui/app/docsh.cxx b/sw/source/ui/app/docsh.cxx
index 0a601cad2d80..7da8e090503b 100644
--- a/sw/source/ui/app/docsh.cxx
+++ b/sw/source/ui/app/docsh.cxx
@@ -790,7 +790,7 @@ void SwDocShell::Draw( OutputDevice* pDev, const JobSetup& rSetup,
pDev->SetBackground();
sal_Bool bWeb = 0 != PTR_CAST(SwWebDocShell, this);
SwPrintData aOpts;
- ViewShell::PrtOle2( pDoc, SW_MOD()->GetUsrPref(bWeb), aOpts, pDev, aRect );
+ SwViewShell::PrtOle2( pDoc, SW_MOD()->GetUsrPref(bWeb), aOpts, pDev, aRect );
pDev->Pop();
if( pOrig )
diff --git a/sw/source/ui/app/docsh2.cxx b/sw/source/ui/app/docsh2.cxx
index d520ea76fca3..1afff5892a25 100644
--- a/sw/source/ui/app/docsh2.cxx
+++ b/sw/source/ui/app/docsh2.cxx
@@ -434,7 +434,7 @@ void SwDocShell::Execute(SfxRequest& rReq)
if( nSlotId )
{
// PagePreview in the WebDocShell
- // is found under Id ViewShell2.
+ // is found under Id VIEWSHELL2.
if( ISA(SwWebDocShell) && SID_VIEWSHELL1 == nSlotId )
nSlotId = SID_VIEWSHELL2;
diff --git a/sw/source/ui/app/swmodul1.cxx b/sw/source/ui/app/swmodul1.cxx
index 6fd4075676b0..dfaf2892d369 100644
--- a/sw/source/ui/app/swmodul1.cxx
+++ b/sw/source/ui/app/swmodul1.cxx
@@ -70,7 +70,7 @@ using namespace ::com::sun::star::view;
using namespace ::com::sun::star::lang;
-static void lcl_SetUIPrefs(const SwViewOption &rPref, SwView* pView, ViewShell* pSh )
+static void lcl_SetUIPrefs(const SwViewOption &rPref, SwView* pView, SwViewShell* pSh )
{
// in FrameSets the actual visibility can differ from the ViewOption's setting
bool bVScrollChanged = rPref.IsViewVScrollBar() != pSh->GetViewOptions()->IsViewVScrollBar();
@@ -143,7 +143,7 @@ void SwModule::ApplyUsrPref(const SwViewOption &rUsrPref, SwView* pActView,
sal_uInt16 nDest )
{
SwView* pCurrView = pActView;
- ViewShell* pSh = pCurrView ? &pCurrView->GetWrtShell() : 0;
+ SwViewShell* pSh = pCurrView ? &pCurrView->GetWrtShell() : 0;
SwMasterUsrPref* pPref = (SwMasterUsrPref*)GetUsrPref( static_cast< sal_Bool >(
VIEWOPT_DEST_WEB == nDest ? sal_True :
@@ -192,7 +192,7 @@ void SwModule::ApplyUsrPref(const SwViewOption &rUsrPref, SwView* pActView,
xViewOpt->SetReadonly( bReadonly );
if( !(*pSh->GetViewOptions() == *xViewOpt) )
{
//is maybe only a ViewShell
pSh->StartAction();
pSh->ApplyViewOptions( *xViewOpt );
((SwWrtShell*)pSh)->SetReadOnlyAvailable(xViewOpt->IsCursorInProtectedArea());
@@ -622,7 +622,7 @@ void SwModule::CheckSpellChanges( bool bOnlineSpelling,
if ( pTmp->GetCurrentViewShell() )
{
pTmp->SpellItAgainSam( bInvalid, bOnlyWrong, bSmartTags );
- ViewShell* pViewShell = 0;
+ SwViewShell* pViewShell = 0;
pTmp->GetEditShell( &pViewShell );
if ( bSmartTags && pViewShell && pViewShell->GetWin() )
pViewShell->GetWin()->Invalidate();
@@ -192,7 +192,7 @@ void SwModule::ApplyUsrPref(const SwViewOption &rUsrPref, SwView* pActView,
if( !(*pSh->GetViewOptions() == *xViewOpt) )
{
- //is maybe only a ViewShell
+ //is maybe only a SwViewShell
pSh->StartAction();
pSh->ApplyViewOptions( *xViewOpt );